==> dartros-0.0.2.tar.gz: lib/src/ros_xmlrpc_common.dart <==
import 'dart:math';
import 'package:dartx/dartx.dart';

enum StatusCode { SUCCESS, FAILURE, ERROR }

Future<dynamic> listenRandomPort(
    int limit, Future<dynamic> Function(int) create) async {
  final random = Random();
  for (final _ in 0.rangeTo(limit)) {
    try {
      final port = random.nextInt(65535 - 1024) + 1024;
      final result = await create(port);
      return result;
    } catch (e) {
      // Do nothing
    }
  }
  throw Exception("Couldn't find a port to listen on");
}

class XMLRPCResponse {
  final StatusCode statusCode;
  final String statusMessage;
  final dynamic value;
  XMLRPCResponse(int status, this.statusMessage, dynamic invalue)
      : statusCode = status.asStatusCode,
        value = invalue;

  bool get success => statusCode == StatusCode.SUCCESS;
  bool get failure => statusCode == StatusCode.FAILURE;
  bool get error => statusCode == StatusCode.ERROR;
  @override
  String toString() {
    return 'XMLRPCResponse: $value, Status $statusCode: $statusMessage';
  }
}

extension StatusCodeAsIntString on StatusCode {
  int get asInt {
    switch (this) {
      case StatusCode.SUCCESS:
        return 1;
      case StatusCode.FAILURE:
        return 0;
      case StatusCode.ERROR:
        return -1;
      default:
        return -1;
    }
  }

  String get asString {
    switch (this) {
      case StatusCode.SUCCESS:
        return 'SUCCESS';
      case StatusCode.FAILURE:
        return 'FAILURE';
      case StatusCode.ERROR:
        return 'ERROR';
      default:
        return 'ERROR';
    }
  }
}

extension AsStatusCode on int {
  StatusCode get asStatusCode {
    switch (this) {
      case 1:
        return StatusCode.SUCCESS;
      case 0:
        return StatusCode.FAILURE;
      case -1:
        return StatusCode.ERROR;
      default:
        return StatusCode.ERROR;
    }
  }
}

==> dartros-0.1.0.tar.gz: lib/src/ros_xmlrpc_common.dart <==
import 'dart:math';
import 'package:dartx/dartx.dart';

enum StatusCode { SUCCESS, FAILURE, ERROR }

Future<T> listenRandomPort<T>(int limit, Future<T> Function(int) create) async {
  final random = Random();
  for (final _ in 0.rangeTo(limit)) {
    try {
      final port = random.nextInt(65535 - 1024) + 1024;
      final result = await create(port);
      return result;
    } on Exception catch (e) {
      // Do nothing
    }
  }
  throw Exception("Couldn't find a port to listen on");
}

class XMLRPCResponse {
  XMLRPCResponse(int status, this.statusMessage, this.value)
      : statusCode = status.asStatusCode;

  final StatusCode statusCode;
  final String statusMessage;
  final Object value;

  bool get success => statusCode == StatusCode.SUCCESS;
  bool get failure => statusCode == StatusCode.FAILURE;
  bool get error => statusCode == StatusCode.ERROR;
  @override
  String toString() =>
      'XMLRPCResponse: $value, Status $statusCode: $statusMessage';
}

extension StatusCodeAsIntString on StatusCode {
  int get asInt {
    switch (this) {
      case StatusCode.SUCCESS:
        return 1;
      case StatusCode.FAILURE:
        return 0;
      case StatusCode.ERROR:
        return -1;
      default:
        return -1;
    }
  }

  String get asString {
    switch (this) {
      case StatusCode.SUCCESS:
        return 'SUCCESS';
      case StatusCode.FAILURE:
        return 'FAILURE';
      case StatusCode.ERROR:
        return 'ERROR';
      default:
        return 'ERROR';
    }
  }
}

extension AsStatusCode on int {
  StatusCode get asStatusCode {
    switch (this) {
      case 1:
        return StatusCode.SUCCESS;
      case 0:
        return StatusCode.FAILURE;
      case -1:
        return StatusCode.ERROR;
      default:
        return StatusCode.ERROR;
    }
  }
}
